@@ -1,29 +1,18 @@
-try:
-    import builtins
-except ImportError:
-    import __builtin__ as builtins
+import builtins
 import itertools
 import re
 import sys
 
 import astroid
 import astroid.nodes
+
+# Disable until pylint uses astroid 2.7
+import astroid.nodes.node_classes  # pylint: disable=no-name-in-module
 import sphinx.util.logging
 
 _LOGGER = sphinx.util.logging.getLogger(__name__)
 
 
-if sys.version_info < (3,):
-    _EXCEPTIONS_MODULE = "exceptions"
-    # getattr to keep linter happy
-    _STRING_TYPES = getattr(builtins, "basestring")
-    _zip_longest = itertools.izip_longest  # pylint: disable=invalid-name,no-member
-else:
-    _EXCEPTIONS_MODULE = "builtins"
-    _STRING_TYPES = (str,)
-    _zip_longest = itertools.zip_longest  # pylint: disable=invalid-name
-
-
 def resolve_import_alias(name, import_names):
     """Resolve a name from an aliased import to its original name.
 
@@ -72,8 +61,8 @@ def get_full_import_name(import_from, name):
     return "{}.{}".format(module_name, partial_basename)
 
 
-def get_full_basename(node, basename):
-    """Resolve a partial base name to the full path.
+def resolve_qualname(node, basename):
+    """Resolve where a node is defined to get its fully qualified name.
 
     :param node: The node representing the base name.
     :type node: astroid.NodeNG
@@ -86,10 +75,16 @@ def get_full_basename(node, basename):
     full_basename = basename
 
     top_level_name = re.sub(r"\(.*\)", "", basename).split(".", 1)[0]
-    lookup_node = node
-    while not hasattr(lookup_node, "lookup"):
-        lookup_node = lookup_node.parent
+    # Disable until pylint uses astroid 2.7
+    if isinstance(
+        node, astroid.nodes.node_classes.LookupMixIn  # pylint: disable=no-member
+    ):
+        lookup_node = node
+    else:
+        lookup_node = node.scope()
+
     assigns = lookup_node.lookup(top_level_name)[1]
+
     for assignment in assigns:
         if isinstance(assignment, astroid.nodes.ImportFrom):
             import_name = get_full_import_name(assignment, top_level_name)
@@ -100,8 +95,10 @@ def get_full_basename(node, basename):
             full_basename = basename.replace(top_level_name, import_name, 1)
             break
         if isinstance(assignment, astroid.nodes.ClassDef):
-            full_basename = "{}.{}".format(assignment.root().name, assignment.name)
+            full_basename = assignment.qname()
             break
+        if isinstance(assignment, astroid.nodes.AssignName):
+            full_basename = "{}.{}".format(assignment.scope().qname(), assignment.name)
 
     if isinstance(node, astroid.nodes.Call):
         full_basename = re.sub(r"\(.*\)", "()", full_basename)
@@ -115,20 +112,17 @@ def get_full_basename(node, basename):
     return full_basename
 
 
-def get_full_basenames(bases, basenames):
-    """Resolve the base nodes and partial names of a class to full names.
+def get_full_basenames(node):
+    """Resolve the partial names of a class' bases to fully qualified names.
 
-    :param bases: The astroid node representing something that a class
-        inherits from.
-    :type bases: iterable(astroid.NodeNG)
-    :param basenames: The partial name of something that a class inherits from.
-    :type basenames: iterable(str)
+    :param node: The class definition node to resolve the bases of.
+    :type: astroid.ClassDef
 
     :returns: The full names.
     :rtype: iterable(str)
     """
-    for base, basename in zip(bases, basenames):
-        yield get_full_basename(base, basename)
+    for base in node.bases:
+        yield _resolve_annotation(base)
 
 
 def _get_const_values(node):
@@ -190,22 +184,13 @@ def get_assign_annotation(node):
     :returns: The type annotation as a string, or None if one does not exist.
     :rtype: str or None
     """
-    annotation = None
-
     annotation_node = None
     try:
         annotation_node = node.annotation
     except AttributeError:
-        # Python 2 has no support for type annotations, so use getattr
-        annotation_node = getattr(node, "type_annotation", None)
+        annotation_node = node.type_annotation
 
-    if annotation_node:
-        if isinstance(annotation_node, astroid.nodes.Const):
-            annotation = node.value
-        else:
-            annotation = annotation_node.as_string()
-
-    return annotation
+    return format_annotation(annotation_node)
 
 
 def is_decorated_with_property(node):
@@ -336,10 +321,7 @@ def is_exception(node):
     :returns: True if the class is an exception, False otherwise.
     :rtype: bool
     """
-    if (
-        node.name in ("Exception", "BaseException")
-        and node.root().name == _EXCEPTIONS_MODULE
-    ):
+    if node.name in ("Exception", "BaseException") and node.root().name == "builtins":
         return True
 
     if not hasattr(node, "ancestors"):
@@ -396,7 +378,7 @@ def get_module_all(node):
                     continue
 
                 if isinstance(elt_name, astroid.Const) and isinstance(
-                    elt_name.value, _STRING_TYPES
+                    elt_name.value, str
                 ):
                     all_.append(elt_name.value)
 
@@ -411,7 +393,7 @@ def _is_ellipsis(node):
 
 
 def merge_annotations(annotations, comment_annotations):
-    for ann, comment_ann in _zip_longest(annotations, comment_annotations):
+    for ann, comment_ann in itertools.zip_longest(annotations, comment_annotations):
         if ann and not _is_ellipsis(ann):
             yield ann
         elif comment_ann and not _is_ellipsis(comment_ann):
@@ -420,41 +402,72 @@ def merge_annotations(annotations, comment_annotations):
             yield None
 
 
-def _format_args(args, defaults=None, annotations=None):
-    values = []
+def _resolve_annotation(annotation):
+    resolved = None
 
-    if args is None:
-        return ""
-
-    if annotations is None:
-        annotations = []
-
-    if defaults is not None:
-        default_offset = len(args) - len(defaults)
-
-    packed = _zip_longest(args, annotations)
-    for i, (arg, annotation) in enumerate(packed):
-        if isinstance(arg, astroid.Tuple):
-            values.append("({})".format(_format_args(arg.elts)))
+    if isinstance(annotation, astroid.Const):
+        resolved = resolve_qualname(annotation, str(annotation.value))
+    elif isinstance(annotation, astroid.Name):
+        resolved = resolve_qualname(annotation, annotation.name)
+    elif isinstance(annotation, astroid.Attribute):
+        resolved = resolve_qualname(annotation, annotation.as_string())
+    elif isinstance(annotation, astroid.Subscript):
+        value = _resolve_annotation(annotation.value)
+        slice_node = annotation.slice
+        if isinstance(slice_node, astroid.Index):
+            slice_node = slice_node.value
+        if isinstance(slice_node, astroid.Tuple):
+            slice_ = ", ".join(_resolve_annotation(elt) for elt in slice_node.elts)
         else:
-            argname = arg.name
-            default_sep = "="
-            if annotation is not None:
-                ann_str = annotation.as_string()
-                if isinstance(annotation, astroid.Const):
-                    ann_str = annotation.value
-                argname = "{}: {}".format(argname, ann_str)
-                default_sep = " = "
-            values.append(argname)
+            slice_ = _resolve_annotation(slice_node)
+        resolved = f"{value}[{slice_}]"
+    elif isinstance(annotation, astroid.Tuple):
+        resolved = (
+            "(" + ", ".join(_resolve_annotation(elt) for elt in annotation.elts) + ")"
+        )
+    elif isinstance(annotation, astroid.List):
+        resolved = (
+            "[" + ", ".join(_resolve_annotation(elt) for elt in annotation.elts) + "]"
+        )
+    else:
+        resolved = annotation.as_string()
 
-            if defaults is not None and i >= default_offset:
-                if defaults[i - default_offset] is not None:
-                    values[-1] += default_sep + defaults[i - default_offset].as_string()
+    if resolved.startswith("typing."):
+        return resolved[len("typing.") :]
 
-    return ", ".join(values)
+    # Sphinx is capable of linking anything in the same module
+    # without needing a fully qualified path.
+    module_prefix = annotation.root().name + "."
+    if resolved.startswith(module_prefix):
+        return resolved[len(module_prefix) :]
+
+    return resolved
 
 
-def format_args(args_node):  # pylint: disable=too-many-branches,too-many-statements
+def format_annotation(annotation):
+    if annotation:
+        return _resolve_annotation(annotation)
+
+    return annotation
+
+
+def _iter_args(args, annotations, defaults):
+    default_offset = len(args) - len(defaults)
+    packed = itertools.zip_longest(args, annotations)
+    for i, (arg, annotation) in enumerate(packed):
+        default = None
+        if defaults is not None and i >= default_offset:
+            if defaults[i - default_offset] is not None:
+                default = defaults[i - default_offset].as_string()
+
+        name = arg.name
+        if isinstance(arg, astroid.Tuple):
+            name = "({})".format(", ".join(x.name for x in arg.elts))
+
+        yield (name, format_annotation(annotation), default)
+
+
+def get_args_info(args_node):  # pylint: disable=too-many-branches,too-many-statements
     result = []
     positional_only_defaults = []
     positional_or_keyword_defaults = args_node.defaults
@@ -465,19 +478,15 @@ def format_args(args_node):  # pylint: disable=too-many-branches,too-many-statem
             : len(args_node.defaults) - len(args)
         ]
 
-    plain_annotations = getattr(args_node, "annotations", ()) or ()
-    func_comment_annotations = getattr(args_node.parent, "type_comment_args", ()) or ()
-    comment_annotations = getattr(args_node, "type_comment_args", []) or []
-    if hasattr(args_node, "type_comment_posonlyargs"):
-        comment_annotations = args_node.type_comment_posonlyargs + comment_annotations
-    else:
-        # astroid used to not expose type comments of positional only arguments,
-        # so pad the comments with the number of positional only arguments.
-        comment_annotations = (
-            [None] * len(getattr(args_node, "posonlyargs", ()))
-        ) + comment_annotations
-    if hasattr(args_node, "type_comment_kwonlyargs"):
-        comment_annotations += args_node.type_comment_kwonlyargs
+    plain_annotations = args_node.annotations or ()
+
+    func_comment_annotations = args_node.parent.type_comment_args or []
+    if args_node.parent.type in ("method", "classmethod"):
+        func_comment_annotations = [None] + func_comment_annotations
+
+    comment_annotations = args_node.type_comment_posonlyargs
+    comment_annotations += args_node.type_comment_args or []
+    comment_annotations += args_node.type_comment_kwonlyargs
     annotations = list(
         merge_annotations(
             plain_annotations,
@@ -486,7 +495,7 @@ def format_args(args_node):  # pylint: disable=too-many-branches,too-many-statem
     )
     annotation_offset = 0
 
-    if getattr(args_node, "posonlyargs", None):
+    if args_node.posonlyargs:
         posonlyargs_annotations = args_node.posonlyargs_annotations
         if not any(args_node.posonlyargs_annotations):
             num_args = len(args_node.posonlyargs)
@@ -494,43 +503,39 @@ def format_args(args_node):  # pylint: disable=too-many-branches,too-many-statem
                 annotation_offset : annotation_offset + num_args
             ]
 
-        result.append(
-            _format_args(
-                args_node.posonlyargs, positional_only_defaults, posonlyargs_annotations
-            )
-        )
-        result.append("/")
+        for arg, annotation, default in _iter_args(
+            args_node.posonlyargs, posonlyargs_annotations, positional_only_defaults
+        ):
+            result.append((None, arg, annotation, default))
+
+        result.append(("/", None, None, None))
 
         if not any(args_node.posonlyargs_annotations):
             annotation_offset += num_args
 
     if args_node.args:
         num_args = len(args_node.args)
-        result.append(
-            _format_args(
-                args_node.args,
-                positional_or_keyword_defaults,
-                annotations[annotation_offset : annotation_offset + num_args],
-            )
-        )
+        for arg, annotation, default in _iter_args(
+            args_node.args,
+            annotations[annotation_offset : annotation_offset + num_args],
+            positional_or_keyword_defaults,
+        ):
+            result.append((None, arg, annotation, default))
+
         annotation_offset += num_args
 
     if args_node.vararg:
-        vararg_result = "*{}".format(args_node.vararg)
-        if getattr(args_node, "varargannotation", None):
-            vararg_result = "{}: {}".format(
-                vararg_result, args_node.varargannotation.as_string()
-            )
+        annotation = None
+        if args_node.varargannotation:
+            annotation = format_annotation(args_node.varargannotation)
         elif len(annotations) > annotation_offset and annotations[annotation_offset]:
-            vararg_result = "{}: {}".format(
-                vararg_result, annotations[annotation_offset].as_string()
-            )
+            annotation = format_annotation(annotations[annotation_offset])
             annotation_offset += 1
-        result.append(vararg_result)
+        result.append(("*", args_node.vararg, annotation, None))
 
-    if getattr(args_node, "kwonlyargs", None):
+    if args_node.kwonlyargs:
         if not args_node.vararg:
-            result.append("*")
+            result.append(("*", None, None, None))
 
         kwonlyargs_annotations = args_node.kwonlyargs_annotations
         if not any(args_node.kwonlyargs_annotations):
@@ -539,31 +544,43 @@ def format_args(args_node):  # pylint: disable=too-many-branches,too-many-statem
                 annotation_offset : annotation_offset + num_args
             ]
 
-        result.append(
-            _format_args(
-                args_node.kwonlyargs,
-                args_node.kw_defaults,
-                kwonlyargs_annotations,
-            )
-        )
+        for arg, annotation, default in _iter_args(
+            args_node.kwonlyargs,
+            kwonlyargs_annotations,
+            args_node.kw_defaults,
+        ):
+            result.append((None, arg, annotation, default))
 
         if not any(args_node.kwonlyargs_annotations):
             annotation_offset += num_args
 
     if args_node.kwarg:
-        kwarg_result = "**{}".format(args_node.kwarg)
-        if getattr(args_node, "kwargannotation", None):
-            kwarg_result = "{}: {}".format(
-                kwarg_result, args_node.kwargannotation.as_string()
-            )
+        annotation = None
+        if args_node.kwargannotation:
+            annotation = format_annotation(args_node.kwargannotation)
         elif len(annotations) > annotation_offset and annotations[annotation_offset]:
-            kwarg_result = "{}: {}".format(
-                kwarg_result, annotations[annotation_offset].as_string()
-            )
+            annotation = format_annotation(annotations[annotation_offset])
             annotation_offset += 1
-        result.append(kwarg_result)
+        result.append(("**", args_node.kwarg, annotation, None))
 
-    return ", ".join(result)
+    if args_node.parent.type in ("method", "classmethod") and result:
+        result.pop(0)
+
+    return result
+
+
+def get_return_annotation(node):
+    """Get the return annotation of a node.
+    :type node: astroid.nodes.FunctionDef
+    """
+    return_annotation = None
+
+    if node.returns:
+        return_annotation = format_annotation(node.returns)
+    elif node.type_comment_returns:
+        return_annotation = format_annotation(node.type_comment_returns)
+
+    return return_annotation
 
 
 def get_func_docstring(node):
@@ -576,6 +593,12 @@ def get_func_docstring(node):
 
     if doc is None and isinstance(node.parent, astroid.nodes.ClassDef):
         for base in node.parent.ancestors():
+            if node.name in ("__init__", "__new__") and base.qname() in (
+                "__builtins__.object",
+                "builtins.object",
+                "builtins.type",
+            ):
+                continue
             for child in base.get_children():
                 if (
                     isinstance(child, node.__class__)
@@ -597,7 +620,11 @@ def get_class_docstring(node):
 
     if doc is None:
         for base in node.ancestors():
-            if base.qname() in ("__builtins__.object", "builtins.object"):
+            if base.qname() in (
+                "__builtins__.object",
+                "builtins.object",
+                "builtins.type",
+            ):
                 continue
             if base.doc is not None:
                 return base.doc
