@@ -5,6 +5,7 @@ import os
 import re
 
 import sphinx.environment
+from sphinx.errors import ExtensionError
 import sphinx.util
 from sphinx.util.console import bold
 import sphinx.util.docstrings
@@ -18,6 +19,7 @@ from .objects import (
     PythonModule,
     PythonMethod,
     PythonPackage,
+    PythonProperty,
     PythonAttribute,
     PythonData,
     PythonException,
@@ -236,12 +238,12 @@ class PythonSphinxMapper(SphinxMapperBase):
             PythonModule,
             PythonMethod,
             PythonPackage,
+            PythonProperty,
             PythonAttribute,
             PythonData,
             PythonException,
         )
     }
-    _OBJ_MAP["property"] = PythonMethod
 
     def __init__(self, app, template_dir=None, url_root=None):
         super(PythonSphinxMapper, self).__init__(app, template_dir, url_root)
@@ -286,6 +288,9 @@ class PythonSphinxMapper(SphinxMapperBase):
         shortened, relative path the package/module
         """
         dir_root_files = list(self._find_files(patterns, dirs, ignore))
+        if not dir_root_files:
+            raise ExtensionError(f"No source files found in: {','.join(dirs)}")
+
         if not self._need_to_load(dir_root_files):
             LOGGER.debug(
                 "[AutoAPI] Skipping read stage because source files have not changed."
@@ -389,11 +394,19 @@ class PythonSphinxMapper(SphinxMapperBase):
             # Some objects require children to establish their docstring
             # or type annotations (eg classes with inheritance),
             # so do this after all children have been created.
-            lines = sphinx.util.docstrings.prepare_docstring(obj.docstring)
-            if lines and "autodoc-process-docstring" in self.app.events.events:
-                self.app.emit(
-                    "autodoc-process-docstring", cls.type, obj.name, None, None, lines
-                )
+            lines = obj.docstring.splitlines()
+            if lines:
+                # Add back the trailing newline that .splitlines removes
+                lines.append("")
+                if "autodoc-process-docstring" in self.app.events.events:
+                    self.app.emit(
+                        "autodoc-process-docstring",
+                        cls.type,
+                        obj.name,
+                        None,
+                        None,
+                        lines,
+                    )
             obj.docstring = "\n".join(lines)
             self._record_typehints(obj)
 
@@ -409,7 +422,7 @@ class PythonSphinxMapper(SphinxMapperBase):
         if (
             isinstance(obj, (PythonClass, PythonFunction, PythonMethod))
             and not obj.overloads
-        ):
+        ) or isinstance(obj, PythonProperty):
             obj_annotations = {}
 
             include_return_annotation = True
