@@ -34,6 +34,11 @@ class Foo(object):
         :type: str
         """
 
+    @property
+    def property_simple(self) -> int:
+        """This property should parse okay."""
+        return 42
+
     def method_okay(self, foo=None, bar=None):
         """This method should parse okay"""
         return True
@@ -128,3 +133,19 @@ class MultilineOne(One):
 
 class Two(One):
     """Two."""
+
+
+def fn_with_long_sig(
+    this,
+    *,
+    function=None,
+    has=True,
+    quite=True,
+    a,
+    long,
+    signature,
+    many,
+    keyword,
+    arguments
+):
+    """A function with a long signature."""
