@@ -9,6 +9,7 @@ from unittest.mock import patch, Mock, call
 import pytest
 import sphinx
 from sphinx.application import Sphinx
+from sphinx.errors import ExtensionError
 import sphinx.util.logging
 
 from autoapi.mappers.python import (
@@ -80,9 +81,9 @@ class TestSimpleModule:
         assert "class Meta" in example_file
         assert "attr2" in example_file
         assert "This is the docstring of an instance attribute." in example_file
-        assert "method_okay(self, foo=None, bar=None)" in example_file
-        assert "method_multiline(self, foo=None, bar=None, baz=None)" in example_file
-        assert "method_tricky(self, foo=None, bar=dict(foo=1, bar=2))" in example_file
+        assert "method_okay(foo=None, bar=None)" in example_file
+        assert "method_multiline(foo=None, bar=None, baz=None)" in example_file
+        assert "method_tricky(foo=None, bar=dict(foo=1, bar=2))" in example_file
 
         # Are constructor arguments from the class docstring parsed?
         assert "Set an attribute" in example_file
@@ -90,6 +91,9 @@ class TestSimpleModule:
         # "self" should not be included in constructor arguments
         assert "Foo(self" not in example_file
 
+        assert "property_simple" in example_file
+        assert "This property should parse okay." in example_file
+
         # Overridden methods without their own docstring
         # should inherit the parent's docstring
         assert example_file.count("This method should parse okay") == 2
@@ -126,6 +130,33 @@ class TestSimpleModule:
 
         assert "Bases:" in example_file
 
+    def test_long_signature(self):
+        example_path = "_build/text/autoapi/example/index.txt"
+        with io.open(example_path, encoding="utf8") as example_handle:
+            example_file = example_handle.read()
+
+        summary_row = """
++------------+--------------------------------------------------------------------------------------------+
+| "fn_with_  | A function with a long signature.                                                          |
+| long_sig"  |                                                                                            |
+| (this, *[, |                                                                                            |
+| function,  |                                                                                            |
+| has,       |                                                                                            |
+| quite])    |                                                                                            |
++------------+--------------------------------------------------------------------------------------------+
+        """.strip()
+        assert summary_row in example_file
+
+        # Check length of truncated signature
+        parts = []
+        for line in summary_row.splitlines()[1:-1]:
+            part = line.split("|")[1].strip()
+            if part.endswith(","):
+                part += " "
+            parts.append(part)
+        sig_summary = "".join(parts)
+        assert len(sig_summary) <= 60
+
 
 class TestMovedConfPy(TestSimpleModule):
     @pytest.fixture(autouse=True, scope="class")
@@ -178,9 +209,9 @@ class TestSimpleStubModule:
         assert "class Meta" in example_file
         assert "Another class var docstring" in example_file
         assert "A class var without a value." in example_file
-        assert "method_okay(self, foo=None, bar=None)" in example_file
-        assert "method_multiline(self, foo=None, bar=None, baz=None)" in example_file
-        assert "method_without_docstring(self)" in example_file
+        assert "method_okay(foo=None, bar=None)" in example_file
+        assert "method_multiline(foo=None, bar=None, baz=None)" in example_file
+        assert "method_without_docstring()" in example_file
 
         # Are constructor arguments from the class docstring parsed?
         assert "Set an attribute" in example_file
@@ -247,7 +278,7 @@ class TestPy3Module:
 
         assert "global_a :A" in example_file
 
-        assert "my_method(self) -> str" in example_file
+        assert "my_method() -> str" in example_file
 
         assert "class example.SomeMetaclass" in example_file
 
@@ -261,14 +292,14 @@ class TestPy3Module:
         assert "overloaded_func(a: Union" not in example_file
         assert "Overloaded function" in example_file
 
-        assert "overloaded_method(self, a: float" in example_file
-        assert "overloaded_method(self, a: str" in example_file
-        assert "overloaded_method(self, a: Union" not in example_file
+        assert "overloaded_method(a: float" in example_file
+        assert "overloaded_method(a: str" in example_file
+        assert "overloaded_method(a: Union" not in example_file
         assert "Overloaded method" in example_file
 
-        assert "overloaded_class_method(cls, a: float" in example_file
-        assert "overloaded_class_method(cls, a: str" in example_file
-        assert "overloaded_class_method(cls, a: Union" not in example_file
+        assert "overloaded_class_method(a: float" in example_file
+        assert "overloaded_class_method(a: str" in example_file
+        assert "overloaded_class_method(a: Union" not in example_file
         assert "Overloaded method" in example_file
 
         assert "undoc_overloaded_func" in example_file
@@ -336,6 +367,11 @@ class TestAnnotationCommentsModule:
 
         assert "global_a :A" in example_file
 
+        assert "class example.B(a: str)" in example_file
+        assert "method(b: list)" in example_file
+        assert "classmethod class_method(c: int)" in example_file
+        assert "static static_method(d: float)" in example_file
+
 
 @pytest.mark.skipif(
     sys.version_info < (3, 8), reason="Positional only arguments need Python >=3.8"
@@ -404,7 +440,7 @@ class TestSimplePackage:
             example_foo_file = example_foo_handle.read()
 
         assert "class example.foo.Foo" in example_foo_file
-        assert "method_okay(self, foo=None, bar=None)" in example_foo_file
+        assert "method_okay(foo=None, bar=None)" in example_foo_file
 
         index_path = "_build/text/index.txt"
         with io.open(index_path, encoding="utf8") as index_handle:
@@ -912,3 +948,21 @@ class TestAutodocTypehintsPackage:
             example2_file = example2_handle.read()
 
         assert "(*int*)" in example2_file
+
+
+def test_no_files_found(builder):
+    """Test that building does not fail when no sources files are found."""
+    with pytest.raises(ExtensionError) as exc_info:
+        builder("pyemptyexample")
+
+    assert os.path.dirname(__file__) in str(exc_info.value)
+
+
+class TestMdSource:
+    @pytest.fixture(autouse=True, scope="class")
+    def built(self, builder):
+        builder(
+            "pyexample",
+            warningiserror=True,
+            confoverrides={"source_suffix": ["md"]},
+        )
