@@ -3,12 +3,12 @@
 templates_path = ["_templates"]
 source_suffix = ".rst"
 master_doc = "index"
-project = u"pyexample"
-copyright = u"2015, readthedocs"
-author = u"readthedocs"
+project = "pyexample"
+copyright = "2015, readthedocs"
+author = "readthedocs"
 version = "0.1"
 release = "0.1"
-language = None
+language = "en"
 exclude_patterns = ["_build"]
 pygments_style = "sphinx"
 todo_include_todos = False
@@ -21,4 +21,4 @@ autoapi_dirs = ["example"]
 autoapi_file_pattern = "*.py"
 autoapi_template_dir = "template_overrides"
 
-exclude_patterns = [autoapi_template_dir]
+exclude_patterns += [autoapi_template_dir]
